CrossToneType

Enum CrossToneType 

pub enum CrossToneType {
    DcsOff = 0,
    ToneDcs = 1,
    DcsCtcss = 2,
    ToneCtcss = 3,
}
Cross-tone type as stored in flash memory byte 0x0E bits [5:4].

Determines how different tone/DCS codes are applied to TX vs RX when cross-tone mode is active.

Per User Manual Chapter 10: cross tone allows separate signaling types for TX and RX when accessing a repeater that uses different encode/decode signaling. Activated by pressing [TONE] 4 times.

ValueEncode (TX)Decode (RX)Display icon
0DCSOffD/O
1ToneDCST/D
2DCSCTCSSD/C
3ToneCTCSST/C

Variants



DcsOff = 0

DCS encode (TX), Off decode (RX). Display: D/O (value 0).



ToneDcs = 1

Tone encode (TX), DCS decode (RX). Display: T/D (value 1).



DcsCtcss = 2

DCS encode (TX), CTCSS decode (RX). Display: D/C (value 2).



ToneCtcss = 3

Tone encode (TX), CTCSS decode (RX). Display: T/C (value 3).

Implementations

Source

impl CrossToneType

pub const COUNT: u8 = 4

Number of valid cross-tone type values (0-3).